psychopy_ext.fmri.GenHRF — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.fmri.GenHRF

class `psychopy_ext.fmri.` `GenHRF`(paths, subjid='subj_01')
  `__init__`(paths, subjid='subj_01')

  Methods

  `__init__`(paths[, subjid]) |
  `gen_test_data`([nruns, tr, blocklen, nconds, ...]) | Generate some fMRI data for testing.
  `hrfs`(weights, blocklen) |
  `prepare_roi`(roi_coords) |
  `spm_hrf_compat`(t[, peak_delay, under_delay, ...]) | SPM HRF function from sum of two gamma PDFs